# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/cong/tab/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/cong/tab/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Cong\\Tab\\": "packages/cong/tab/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Cong\Tab\Providers\TabServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Tab'  => Cong\Tab\Facades\Tab::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Cong\\TabTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Cong\Tab\Providers\TabServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Cong\Tab\Providers\TabServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Cong\Tab\Providers\TabServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/tab/{modulename}

**User**

    http://path-to-route-folder/user/tab/{modulename}

**Public**

    http://path-to-route-folder/tabs


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/tab/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/tab/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/tab/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/tab/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/tab/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/tab/{modulename}/{slug}
    METHOD: GET